==> hirehive-ui-1.10.13.tgz: package/src/Actions/ToolTip.js <==
import { createPopper } from "@popperjs/core";

import Tip from "../ToolTips/Tip.svelte";

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const toolTip = (node, options) => {
  let popperInstance;
  let componentInstance;
  let isActive = false;

  let text = options.text;

  // add small delay before showing tooltip
  node.addEventListener("mouseenter", show);
  node.addEventListener("focusin", show);

  node.addEventListener("mouseleave", hide);
  node.addEventListener("click", hide);
  node.addEventListener("focusout", hide);

  let tip;

  function show() {
    // prevent from two tips being created for tool tip if hover and focused
    if (isActive) {
      return;
    }

    // delay to tooltip displaying
    componentInstance = new Tip({
      target: document.body,
      props: { text },
    });

    // this will be the tip from the component instance;
    tip = componentInstance.$$.ctx[0];
    tip.setAttribute("data-show", "");
    buildPopper(tip);
    isActive = true;
  }

  const buildPopper = (tipNode) => {
    popperInstance = createPopper(node, tipNode, {
      placement: options.position,
      strategy: "fixed",
      modifiers: [
        {
          name: "offset",
          options: {
            offset: [0, 8],
          },
        },
        {
          name: "flip",
          options: {
            rootBoundary: "document",
          },
        },
      ],
    });
  };

  function hide() {
    if (tip) {
      tip.setAttribute("data-show", "");
    }

    if (popperInstance) {
      popperInstance.destroy();
      popperInstance = null;
      componentInstance.$destroy();
    }

    isActive = false;
  }

  return {
    destroy() {
      node.removeEventListener("mouseover", show);
      node.removeEventListener("mouseout", hide);
      node.removeEventListener("focusin", show);
      node.removeEventListener("focusout", hide);
    },
    update(options) {
      text = options.text;
    },
  };
};

==> hirehive-ui-1.12.1.tgz: package/src/Actions/ToolTip.js <==
import { createPopper } from "@popperjs/core";

import Tip from "../ToolTips/Tip.svelte";

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const toolTip = (node, options) => {
  let popperInstance;
  let componentInstance;
  let isActive = false;

  let text = options.text;

  // add small delay before showing tooltip
  node.addEventListener("mouseenter", show);
  node.addEventListener("mouseleave", hide);

  node.addEventListener("focusin", show);
  node.addEventListener("focusout", hide);

  node.addEventListener("click", hide);

  let tip;

  function show() {
    // prevent from two tips being created for tool tip if hover and focused
    if (isActive) {
      return;
    }

    // delay to tooltip displaying
    componentInstance = new Tip({
      target: document.body,
      props: { text },
    });

    // this will be the tip from the component instance;
    tip = componentInstance.$$.ctx[0];
    tip.setAttribute("data-show", "");
    buildPopper(tip);
    isActive = true;
  }

  const buildPopper = (tipNode) => {
    popperInstance = createPopper(node, tipNode, {
      placement: options.position,
      strategy: "fixed",
      modifiers: [
        {
          name: "offset",
          options: {
            offset: [0, 8],
          },
        },
        {
          name: "flip",
          options: {
            rootBoundary: "document",
          },
        },
      ],
    });
  };

  function hide() {
    if (tip) {
      tip.setAttribute("data-show", "");
    }

    if (popperInstance) {
      popperInstance.destroy();
      popperInstance = null;
    }

    if (componentInstance) {
      componentInstance.$destroy();
    }

    isActive = false;
  }

  return {
    destroy() {
      node.removeEventListener("mouseenter", show);
      node.removeEventListener("mouseleave", hide);
      node.removeEventListener("focusin", show);
      node.removeEventListener("focusout", hide);
      node.removeEventListener("click", hide);

      hide();
    },
    update(options) {
      text = options.text;
    },
  };
};
